#!/bin/sh

#####################################################
#
# Centrify DirectAudit 
# In order to download and install tenant root CA cert
# Copyright (C) 2006-2020 Centrify Corp
#
#####################################################

Usage()
{
cat <<-END_USAGE

This script is used to install tenant root certificate.
Only the root can run this script.

Usage:
    $PROGRAM_NAME [Certificate File]
    
    Note: The tenant root certificate will be installed as follows:
        Debian/Ubuntu:  <Certificate Name>.crt under /usr/local/share/ca-certificates/centrify/
        RHEL/Centos:    <Certificate Name>.cer under /etc/pki/ca-trust/source/anchors/
        Suse:           <Certificate Name>.cer under /usr/share/pki/trust/anchors/
        CoreOS:         <Certificate name>.pem under /etc/ssl/certs/

END_USAGE
}

CheckRoot()
{
    if [ -z "$UID" ]; then
        if [ -x /usr/xpg4/bin/id ]; then
            UID=`/usr/xpg4/bin/id -u`
        elif [ -x /usr/bin/id ]; then
            UID=`/usr/bin/id -u`
        elif [ -x /bin/id ]; then
            UID=`/bin/id -u`
        fi
    fi
    if [ -z "$UID" ]; then
        echo "Error: Unable to determine current UID, this script must be executed by root, trying to continue operation"
        exit 1
    elif [ $UID -ne 0 ]; then
        echo "Error: This script must be executed by root."
        exit 1
    fi
}

PROGRAM_NAME="`basename $0`"

if [ ! -x "/opt/centrify/perl/scripts/detect_os.pl" ] || [ -x "opt/centrify/bin/instcert.sh" ]; then
    echo "The Centrify Agent for Linux doesn't appear to be properly installed on this system."
    exit 1
fi

CheckRoot

if [ $# -ne 1 ]; then
    Usage
    exit 1
fi

if [ ! -f "$1" ]; then
    echo "$1 does not exist!!!"
    exit 1
fi

CERTFILE=$1
#ensure this is a absolute path
case $CERTFILE in
    /*)
        ;;
    *)
        echo "$CERTFILE is not a absolute path!!!"
        exit 1
esac

CERT_NAME=`basename $CERTFILE | cut -f 1 -d '.'`

DAD_DATA_DIR="/var/centrifyda"
OPENSSL_CMD=/usr/share/centrifydc/libexec/openssl
CERTFILE_CRT="${DAD_DATA_DIR}/${CERT_NAME}.crt"
CERTFILE_PEM="${DAD_DATA_DIR}/${CERT_NAME}.pem"

# For different platforms, some specified file extension might be needed:
#   Debian/Ubuntu: <xxxx>.crt
#   CoreOS: <xxxx>.pem
#
PLATFORM=`/opt/centrify/perl/scripts/detect_os.pl | sed -e 's/_.*//'`
case $PLATFORM in
    ubuntu|debian)
        if [ -f $CERTFILE_CRT ]; then
            rm -f $CERTFILE_CRT
        fi
        $OPENSSL_CMD x509 -inform PEM -in $CERTFILE -out $CERTFILE_CRT
        /opt/centrify/bin/instcert.sh $CERTFILE_CRT
        ;;
    coreos)
        if [ -f $CERTFILE_PEM ]; then
            rm -f $CERTFILE_PEM
        fi        
        $OPENSSL_CMD x509 -inform PEM -in $CERTFILE -out $CERTFILE_PEM
        /opt/centrify/bin/instcert.sh $CERTFILE_PEM
        ;;
    *)
        /opt/centrify/bin/instcert.sh $CERTFILE
        ;;
esac

# Clean up certificate file
if [ -f $CERTFILE_CRT ]; then
    rm -f $CERTFILE_CRT
fi

if [ -f $CERTFILE_PEM ]; then
    rm -f $CERTFILE_PEM
fi
