#!/bin/sh /usr/share/centrifydc/perl/run

##############################################################################
#
# Copyright (C) 2014-2020 Centrify Corporation. All rights reserved.
#
# this script checks what pam structure is running on machine,
# and choose the right autoedit Perl script to add Centrifydc code into pam file
#
# arguments:
#       please see autoedit_configure.pm
# return:
#       0 if succeed
#       1 if meet error
#
##############################################################################

use warnings;
use strict;
use lib "/usr/share/centrifydc/perl";
use lib "/usr/share/centrifydc/scripts";
use CentrifyDC::Include;

use autoedit_file_lock;
use CentrifyDC::GP::General qw(:debug :system);

my $scp_dir = "/usr/share/centrifydc/scripts";
my $cfg_dir = "/etc";

# see if pam.d dir was defined in @ARGV
# do not use Getopt::Long here, we will call it later
if (scalar(@ARGV))
{
    my $dir = join " ", @ARGV;
    $dir =~ /--cfg_dir\s+(\S+)/;
    $cfg_dir = defined $1 ? $1 : $cfg_dir;
}

# use "-e" here, because we accept it is a symlink
if (-e "$cfg_dir/pam.conf")
{
    my $cmd  = "$scp_dir/autoedit_default_pam_conf.pl ";
    $cmd .= join " ", @ARGV;
    my $ret = RunCommand($cmd);
    # got 1 if have anything wrong
    if ($ret == 1)
    {
        exit 1;
    }
}

# For Solaris 11.1, the PAM search order is look for pam.conf first, 
# if service not found in pam.conf, look in pam.d ; so, we update both. 
if (-e "$cfg_dir/pam.d/system-auth"
    || -e "$cfg_dir/pam.d/common-auth")
{
    my $cmd  = "$scp_dir/autoedit_default_pam_d_stack.pl ";
    $cmd .= join " ", @ARGV;
    my $ret = RunCommand($cmd);
    # got 1 if have anything wrong
    if ($ret == 1)
    {
        exit 1;
    }
}
# use "-e" here, because we accept it is a symlink
elsif (-e "$cfg_dir/pam.d")
{
    my $cmd  = "$scp_dir/autoedit_default_pam_d_general.pl ";
    $cmd .= join " ", @ARGV;
    # my $ret = RunCommand($cmd);
    my $ret = RunCommand($cmd);
    # got 1 if have anything wrong
    if ($ret == 1)
    {
        exit 1;
    }
}

foreach ("system-auth", "password-auth")
{
    my $cfgName = "$cfg_dir/pam.d/$_";

    if (-l $cfgName)
    {
        my $flock = autoedit_file_lock::new("$cfgName");
        if (!defined $flock)
        {
            warn "cannot lock file $cfgName";
            exit 1;
        }

        my $realName = TraverseSymLink($cfgName);
        if ($realName !~ /cdc$/)
        {
            rename "$realName", "$realName.cdc";
            unlink "$cfgName";
            symlink "$realName.cdc", "$cfgName";
        }
    }
}

exit 0;

